@@ -4,6 +4,9 @@
 module RIO.State
   (
     Control.Monad.State.MonadState (..)
+  , Control.Monad.State.gets
+  , Control.Monad.State.modify
+  , Control.Monad.State.modify'
   ) where
 
 import qualified Control.Monad.State
